@@ -140,6 +140,21 @@ mod polymorphic {
         pub open: bool,
     }
 
+    /// A request to run an export markdown task.
+    #[derive(Debug, Clone)]
+    pub struct OnExportMdRequest {
+        /// The path of the document to export.
+        pub path: PathBuf,
+        /// The processor package to use for the export.
+        pub processor: Option<String>,
+        /// The export task to run.
+        pub task: ProjectTask,
+        /// Whether to write to file.
+        pub write: bool,
+        /// Whether to open the exported file(s) after the export is done.
+        pub open: bool,
+    }
+
     /// The response to an export request.
     #[derive(Debug, Clone, Serialize, Deserialize)]
     #[serde(untagged, rename_all = "camelCase")]
@@ -215,6 +230,8 @@ mod polymorphic {
     pub enum CompilerQueryRequest {
         /// A request to run an export task.
         OnExport(OnExportRequest),
+        /// A request to run an export markdown task.
+        OnExportMd(OnExportMdRequest),
         /// A request to get the hover information.
         Hover(HoverRequest),
         /// A request to go to the definition.
@@ -281,6 +298,7 @@ mod polymorphic {
             use FoldRequestFeature::*;
             match self {
                 Self::OnExport(..) => Mergeable,
+                Self::OnExportMd(..) => Mergeable,
                 Self::Hover(..) => PinnedFirst,
                 Self::GotoDefinition(..) => PinnedFirst,
                 Self::GotoDeclaration(..) => PinnedFirst,
@@ -318,6 +336,7 @@ mod polymorphic {
         pub fn associated_path(&self) -> Option<&Path> {
             Some(match self {
                 Self::OnExport(..) => return None,
+                Self::OnExportMd(..) => return None,
                 Self::Hover(req) => &req.path,
                 Self::GotoDefinition(req) => &req.path,
                 Self::GotoDeclaration(req) => &req.path,
