@@ -1,6 +1,4 @@
-use lsp_types::ChangeAnnotation;
-
-use crate::{do_rename_file, edits_to_document_changes, prelude::*};
+use crate::{create_change_annotation, do_rename_file, edits_to_document_changes, prelude::*};
 
 /// Handle [`workspace/willRenameFiles`] request is sent from the client to the
 /// server.
@@ -37,25 +35,21 @@ impl SemanticRequest for WillRenameFilesRequest {
             })
             .collect::<Option<Vec<()>>>()?;
         log::info!("did rename edits: {edits:?}");
-        let document_changes = edits_to_document_changes(edits);
+        let document_changes = edits_to_document_changes(edits, None);
         if document_changes.is_empty() {
             return None;
         }
 
-        let mut change_annotations = HashMap::new();
-        change_annotations.insert(
-            "Typst Rename Files".to_string(),
-            ChangeAnnotation {
-                label: "Typst Rename Files".to_string(),
-                needs_confirmation: Some(true),
-                description: Some("Rename files should update imports".to_string()),
-            },
-        );
+        let change_annotations = Some(create_change_annotation(
+            "Typst Rename Files",
+            true,
+            Some("Renaming files should update imports".to_string()),
+        ));
 
         Some(WorkspaceEdit {
             changes: None,
             document_changes: Some(lsp_types::DocumentChanges::Operations(document_changes)),
-            change_annotations: Some(change_annotations),
+            change_annotations,
         })
     }
 }
