@@ -216,7 +216,7 @@ impl CompileOnceArgs {
 ///
 /// This function will return an error if the argument contains no equals sign
 /// or contains the key (before the equals sign) is empty.
-fn parse_input_pair(raw: &str) -> Result<(String, String), String> {
+pub fn parse_input_pair(raw: &str) -> Result<(String, String), String> {
     let (key, val) = raw
         .split_once('=')
         .ok_or("input must be a key and a value separated by an equal sign")?;
