@@ -174,7 +174,7 @@ impl ServerState {
                 allow_overlapping_token: const_config.tokens_overlapping_token_support,
                 allow_multiline_token: const_config.tokens_multiline_token_support,
                 remove_html: !config.support_html_in_markdown,
-                support_client_codelens: true,
+                support_client_codelens: config.support_client_codelens,
                 extended_code_action: config.extended_code_action,
                 completion_feat: config.completion.clone(),
                 color_theme: match config.color_theme.as_deref() {
