@@ -1,5 +1,6 @@
 import type { EditorTool } from "../../tools";
 import docsView from "../../tools/docs-view";
+import exporter from "../../tools/exporter";
 import fontView from "../../tools/font-view";
 import profileServer from "../../tools/profile-server";
 import summary from "../../tools/summary";
@@ -8,6 +9,7 @@ import templateGallery from "../../tools/template-gallery";
 import tracing from "../../tools/tracing";
 
 export const tools: EditorTool[] = [
+  exporter,
   templateGallery,
   summary,
   tracing,
